Gressmann, F., Király, F. J., Mateen, B., & Oberhauser, H. (2018). Probabilistic supervised learning. ArXiv:1801.00753 [Cs, Math, Stat]. Retrieved from http://arxiv.org/abs/1801.00753 ::

    @article{skpro,
      archivePrefix = {arXiv},
      eprinttype = {arxiv},
      eprint = {1801.00753},
      primaryClass = {cs, math, stat},
      title = {Probabilistic Supervised Learning},
      url = {http://arxiv.org/abs/1801.00753},
      urldate = {2018-01-03},
      date = {2018-01-02},
      author = {Gressmann, Frithjof and Kir{\'a}ly, Franz J. and Mateen, Bilal and Oberhauser, Harald}
    }
